
***********************************
********** RESULTS - Benin ********
***********************************

*import data

use "${Benin_data}/FEMALE2011_clean_long.dta", replace
*****************************************************
************ AVERAGE TREATMENT EFFECT ***************
*****************************************************
label var treated_1 "Treatment follow-up 1"
label var treated_2 "Treatment follow-up 2"

reg  f07_ treated_1 treated_2 time  Age age_square hh_head nbs_children_over_3   polygamous_hh_2 polygamous_hh_3 married_couple  literate i.religion i.ethnie i.strata if Age<50 , vce(cluster codevil)
sum  f07_  if treated_1==0 & Age<50 & time==0
local C_mean  = r(mean)
sum  f07_  if treated_2==0 & Age<50 & time==1
local C_mean_2 = r(mean)
test _b[treated_1]=_b[treated_2]
local p_val = r(p)
outreg2  using "${Benin_output}/ATE.xls", excel dec(3) ctitle("Number of children") keep( treated_1 treated_2 )  addstat(Control group mean period1, `C_mean', Control group mean period2, `C_mean_2', p_val, `p_val') label replace




*****************************************************
************ HETEROGENEOUS TREATMENT EFFECT *********
*****************************************************

*******************************************Depending on: at least one son at baseline 
gen had_a_son_before_2010_1 = f08 >1
replace had_a_son_before_2010_1= . if f08==.


reg  f07_ treated_1 treated_2  time      Age age_square  hh_head nbs_children_over_3 polygamous_hh_2 polygamous_hh_3  literate i.religion i.ethnie  i.strata if Age<50 & had_a_son_before_2010_1==0 , vce(cluster codevil)
sum  f07_  if treated_1==0 & Age<50 & time==0 & had_a_son_before_2010_1 ==0
local C_mean = r(mean)
outreg2  using "${Benin_output}/HTE_son.xls", excel dec(3) ctitle("No son") keep( treated_1 treated_2   )  addstat(Control group mean period1, `C_mean') label replace
 
reg  f07_ treated_1 treated_2  time     Age age_square  hh_head nbs_children_over_3 polygamous_hh_2 polygamous_hh_3  literate i.religion i.ethnie i.strata 	  if Age<50 & had_a_son_before_2010_1==1   , vce(cluster codevil)
sum  f07_  if treated_1==0 & Age<50 & time==0 & had_a_son_before_2010_1==1
local C_mean   = r(mean)
outreg2  using "${Benin_output}/HTE_son.xls", excel dec(3) ctitle("At least one son") keep( treated_1 treated_2  )  addstat(Control group mean period1, `C_mean') label append

reg  f07_ treated_1 treated_2 time       Age age_square  hh_head nbs_children_over_3 polygamous_hh_2 polygamous_hh_3  literate i.religion i.ethnie  i.strata  if   Age<50& had_a_son_before_2010_1==0  
est store reg1
reg f07_ treated_1 treated_2 time       Age age_square  hh_head nbs_children_over_3 polygamous_hh_2 polygamous_hh_3  literate i.religion i.ethnie  i.strata if Age<50 & had_a_son_before_2010_1==1  
est store reg2


suest reg1 reg2, vce(cluster codevil)
test [reg1_mean]treated_1 =[reg2_mean]treated_1
local p_val_1 = r(p)
test [reg1_mean]treated_2=[reg2_mean]treated_2
local p_val_2 = r(p)
	
			
putexcel set "${Benin_output}/HTE_son_test.xlsx", sheet("test diff")  replace
 putexcel A1="p-val 1"  B1="p-val 2"
  putexcel A2=`p_val_1' B2= `p_val_2'




*******************************************Depending on: women has rivals

*import the rival var 
egen temporary_ID = concat(hsclust hsstruct hsnumber)
rename _merge _merge5
merge m:1 temporary_ID using "/Users/mathildesage/Library/Mobile Documents/com~apple~CloudDocs/Fertility paper/Benin PFR data/data/Benin PFR data - raw/XH.dta", keepusing(husband_children_previous_union)

drop if _merge==2

gen rivals = (husband_children_previous_union>0 )
replace rivals=. if husband_children_previous_union==.
label var rivals "Woman has rivals from previous union"

label var had_a_son_before_2010_1 "Had a son before treatment"

gen had_a_son_before_treat_1 = had_a_son_before_2010_1*treated_1
label var had_a_son_before_treat_1 "Women had son from head before the treatment X treat_1"

gen had_a_son_before_treat_2 = had_a_son_before_2010_1*treated_2
label var had_a_son_before_treat_2 "Women had son from head before the treatment X treat_2"
 
 
local son = "had_a_son_before_2010_1 had_a_son_before_treat_1 had_a_son_before_treat_2"

reg  f07_ treated_1 treated_2 `son' time     polygamous_hh_2 polygamous_hh_3 married_couple  literate Age age_square  hh_head  i.strata nbs_children_over_3  i.religion i.ethnie if Age<50 & rivals==0 , vce(cluster codevil)
sum  f07_  if treated_1==0 & Age<50 & time==0 & rivals==0

outreg2  using "${Benin_output}/HTE_rivals_son.xls", excel dec(3) ctitle("No rivals") keep( treated_1 treated_2 `son' )  addstat(Control group mean period1, `C_mean') label replace
*i.religion i.ethnie
 
reg  f07_ treated_1 treated_2 `son' time     polygamous_hh_2 polygamous_hh_3 married_couple  literate Age age_square  hh_head   nbs_children_over_3 i.strata  i.religion i.ethnie if Age<50 & rivals==1 , vce(cluster codevil)
sum  f07_ if treated_1==0 & Age<50 & time==0 & rivals==1
local C_mean = r(mean)

outreg2  using "${Benin_output}/HTE_rivals_son.xls", excel dec(3) ctitle("Has rivals") keep( treated_1 treated_2 `son' )  addstat(Control group mean period1,  `C_mean') label append


local son = "had_a_son_before_2010_1 had_a_son_before_treat_1 had_a_son_before_treat_2"

reg  f07_  treated_1 treated_2 `son' time   married_couple  literate Age age_square  hh_head i.religion i.ethnie polygamous_hh_2 polygamous_hh_3 nbs_children_over_3 i.strata if Age<50 & rivals==0
est store reg1
reg  f07_  treated_1 treated_2 `son' time   married_couple  literate Age age_square  hh_head i.religion i.ethnie polygamous_hh_2 polygamous_hh_3 i.strata nbs_children_over_3 if Age<50 & rivals==1
est store reg2

suest reg1 reg2, vce(cluster codevil)
test [reg1_mean]treated_1 =[reg2_mean]treated_1
local p_val_1 = r(p)
test [reg1_mean]treated_2 =[reg2_mean]treated_2
local p_val_2= r(p)

			
putexcel set "${Benin_output}/HTE_rivals_son_test.xlsx", sheet("test diff")  replace
 putexcel A1="p-val 1"  B1="p-val 2"
  putexcel A2=`p_val_1' B2= `p_val_2'

*******************************************Depending on: own land at least one plot on which she has full decision power 


merge m:1 household_ID using "${Benin_data}/Women_module_base_for_land_study_for_merge.dta", keepusing(land_owned_wo_full_d ) gen(Merge_land_info)


reg  f07_ treated_1 treated_2 time nbs_children_over_3  married_couple  polygamous_hh_2 polygamous_hh_3 literate Age age_square  hh_head   i.strata i.religion i.ethnie if Age<50 & land_owned_wo_full_d==1, vce(cluster codevil)
     sum  f07_no_out if treated_1==0 & Age<50 & time==0 & land_owned_wo_full_d==1
   local C_mean  = r(mean)
        sum  f07_no_out if treated_2==0 & Age<50 & time==1 & land_owned_wo_full_d==1
   local C_mean_2 = r(mean)
 outreg2  using "${Benin_output}/HTE_own_land.xls", excel dec(3) ctitle("Women owns at least one land on which she has full decision power") keep( treated_1 treated_2  )  addstat(Control group mean period1, `C_mean', Control group mean period2, `C_mean_2') label replace

 reg  f07_ treated_1 treated_2  time  nbs_children_over_3  married_couple  polygamous_hh_2 polygamous_hh_3 literate Age age_square  hh_head  i.strata i.religion i.ethnie if Age<50 & land_owned_wo_full_d==0, vce(cluster codevil)
     sum  f07_no_out  if treated_1==0 & Age<50 & time==0 & land_owned_wo_full_d==0
   local  C_mean  = r(mean)
        sum  f07_no_out  if treated_2==0 & Age<50 & time==1 & land_owned_wo_full_d==0
   local C_mean_2 = r(mean)
 outreg2  using "${Benin_output}/HTE_own_land.xls", excel dec(3) ctitle("Women does not own at least one land on which she has full decision power") keep( treated_1 treated_2  )  addstat(Control group mean period1, `C_mean', Control group mean period2, `C_mean_2') label append

 reg  f07_ treated_1 treated_2 time   nbs_children_over_3  married_couple  polygamous_hh_2 polygamous_hh_3 literate Age age_square  hh_head   i.strata i.religion i.ethnie if Age<50 & land_owned_wo_full_d==1
 est store reg1
  reg  f07_ treated_1 treated_2  time  nbs_children_over_3  married_couple  polygamous_hh_2 polygamous_hh_3 literate Age age_square  hh_head   i.strata i.religion i.ethnie if Age<50 & land_owned_wo_full_d==0
 est store reg2

suest reg1 reg2, vce(cluster codevil)
			test [reg1_mean]treated_1 =[reg2_mean]treated_1 
			test [reg1_mean]treated_2=[reg2_mean]treated_2


*******************************************Robustness checks: Son and nbs of children interacted with treatment

gen nbs_T1 = (nbs_children_over_3*treated_1)
 replace nbs_T1=. if nbs_children_over_3==. 
 label var nbs_T1 "Number of children X treatment period 1"
 
 gen nbs_T2 = (nbs_children_over_3*treated_2)
 replace nbs_T2=. if nbs_children_over_3==. 
 label var nbs_T2 "Number of children X treatment period 2"

 
local son = "had_a_son_before_2010_1 had_a_son_before_treat_1 had_a_son_before_treat_2"


  reg  f07_ treated_1 treated_2 time  `son'   nbs_T1 nbs_T2 nbs_children_over_3 married_couple  literate Age age_square  hh_head  polygamous_hh_2 polygamous_hh_3 i.religion i.ethnie i.strata if Age<50 , vce(cluster codevil)
     sum  f07_  if treated_1==0 & Age<50 & time==0
   local C_mean  = r(mean)
        sum  f07_  if treated_2==0 & Age<50 & time==1
   local C_mean_2 = r(mean)
 outreg2  using "${Benin_output}/son_nbs_children.xls", excel dec(3) ctitle("Nbs of children at endline") keep( treated_1 treated_2   `son' nbs_T1 nbs_T2 nbs_children_over_3  )  addstat(Control group mean period1, `C_mean', Control group mean period2, `C_mean_2') label replace


*******************************************Impact on labour supply



egen id_2 = concat(hsclust hsstruct hsnumber m00), punct(-) 
  
merge m:1 id_2 using "${Benin_data}/XREE_temp.dta", keepusing(ee02 ee03 ee04 ee05 ee06 ee07) gen(merge_labour_supply)

drop if merge_labour_supply==2 

  
  gen hours_worked_last7 = ee05
  replace hours_worked_last7=0 if ee02==2 
  replace hours_worked_last7=. if ee02 ==1 & ee05==.
  label var hours_worked_last7 "Number of hours worked employed in the last 7 days"
  
  gen month_worked_last12 = ee04
  replace month_worked_last12=0 if  ee03==2
  replace month_worked_last12=. if ee03==1 & ee04==. 
  label var month_worked_last12 "Number of months worked employed the last 12 months"
  
  
   reg  hours_worked_last7 treated  nbs_children_over_3  married_couple  literate Age age_square  hh_head  polygamous_hh_2 polygamous_hh_3 i.religion i.ethnie i.strata if Age<50 & time==0, vce(cluster codevil)
     sum  hours_worked_last7 if treated==0 & Age<50 & time==0
   local C_mean  = r(mean)
    outreg2  using "${Benin_output}/labour_supply.xls", excel dec(3) ctitle("Hours worked employed the last 7 days") keep( treated   )  addstat(Control group mean period1, `C_mean') label replace

 

 reg month_worked_last12  treated  nbs_children_over_3  married_couple  literate Age age_square  hh_head  polygamous_hh_2 polygamous_hh_3 i.religion i.ethnie i.strata if Age<50 & time==0, vce(cluster codevil)
     sum  month_worked_last12  if treated==0 & Age<50 & time==0
   local C_mean  = r(mean)

 outreg2  using "${Benin_output}/labour_supply.xls", excel dec(3) ctitle("Months worked employed the last 12 months") keep( treated  )  addstat(Control group mean period1, `C_mean') label  append




