

***********************************
********** RESULTS - DOT **********
***********************************


*Import data
use "${DOT_data}/Women Entrepreneurship Development Project_DOT_clean.dta", replace

***Labeling

label var head_hh "Women is head of household"

label var DOT_1 "treatment period 1"
label var DOT_2 "treatment period 2"

**Importing the hh asset index var

merge m:1 wedp_id using "${DOT_data}/Women Entrepreneurship Development Project_MainIE_Fertility_07252019.dta", keepusing(HH_Asset_Index_bl) gen(merge_3)

drop if merge_3 ==2

*****************************************************
************ AVERAGE TREATMENT EFFECT ***************
*****************************************************

******Outcome : number of children at endline

reg n_children_t  DOT_1 DOT_2 number_children_bl time married_couple WEDP_loan education_level_bl  Age_bl Age_bl_square head_hh bl_pi6 plan_have_children no_children_bl  HH_Asset_Index_bl if Age_bl<50 , vce(cluster wedp_id) 
sum n_children_t  if treatment==0 
  local C_mean = r(mean)
  test _b[DOT_1 ] =_b[DOT_2 ]
  local p_val = r(p)
outreg2  using "${DOT_output}/ATE.xls",  excel dec(3) ctitle("Number of children") keep( DOT_1 DOT_2 ) addstat(Control group mean -follow-up 1, `C_mean', p-val , `p_val')  label replace



******Outcome : at least one child post treatment




reg child_post_d  DOT_1 DOT_2 number_children_bl time married_couple WEDP_loan education_level_bl  Age_bl Age_bl_square head_hh bl_pi6 plan_have_children no_children_bl HH_Asset_Index_bl  if Age_bl<50 , vce(cluster wedp_id) 
sum child_post_d  if treatment==0 
  local C_mean = r(mean)
  test _b[DOT_1 ] =_b[DOT_2 ]
  local p_val = r(p)
outreg2  using "${DOT_output}/ATE.xls",  excel dec(3) ctitle("At least one child post treatment") keep( DOT_1 DOT_2 ) addstat(Control group mean -follow-up 1, `C_mean', p-val , `p_val')  label append


***********************************************************
************ HETEROGENEOUS TREATMENT EFFECT ***************
***********************************************************

************ DEPENDING ON: AT LEAST ONE SON AT BASELINE ***************

reg n_children_t  DOT_1  DOT_2  number_children_bl time married_couple WEDP_loan education_level_bl  Age_bl Age_bl_square head_hh bl_pi6 plan_have_children no_children_bl HH_Asset_Index_bl if Age_bl<50 & at_least_son==0, vce(cluster wedp_id) 
  sum  n_children_t if treatment==0 & at_least_son==0 & Age_bl<50
    local C_mean = r(mean)
outreg2  using "${DOT_output}/HTE_son.xls", excel dec(3) ctitle("No son") keep( DOT_1  DOT_2   ) addstat(Control group mean , `C_mean')    label replace

reg n_children_t  DOT_1  DOT_2  number_children_bl time married_couple WEDP_loan education_level_bl  Age_bl Age_bl_square head_hh bl_pi6  plan_have_children no_children_bl HH_Asset_Index_bl if Age_bl<50 & at_least_son==1, vce(cluster wedp_id) 
  sum  n_children_t if treatment==0 & at_least_son==1 & Age_bl<50
    local C_mean = r(mean)
outreg2  using "${DOT_output}/HTE_son.xls", excel dec(3) ctitle("At least one son") keep(  DOT_1 DOT_2   ) addstat(Control group mean , `C_mean') label append



	quietly reg n_children_t  DOT_1  DOT_2  number_children_bl time married_couple  WEDP_loan education_level_bl  Age_bl Age_bl_square head_hh bl_pi6 plan_have_children no_children_bl HH_Asset_Index_bl if Age_bl<50 & at_least_son==0
 est store reg1
 reg n_children_t  DOT_1  DOT_2   number_children_bl time married_couple  WEDP_loan education_level_bl  Age_bl Age_bl_square head_hh bl_pi6 plan_have_children no_children_bl HH_Asset_Index_bl if Age_bl<50 & at_least_son==1
 est store reg2

suest reg1 reg2, vce(cluster wedp_id)
			test [reg1_mean]DOT_1 =[reg2_mean]DOT_1 
			local p_val_1 = r(p)
			test [reg1_mean]DOT_2=[reg2_mean]DOT_2
			local p_val_2 = r(p)
 putexcel set "${DOT_output}/HTE_son_test.xlsx", sheet("test diff")  replace
 putexcel A1="p-val period 1" B1="p-val period 2"
  putexcel A2=`p_val_1' B2=`p_val_2'

 

			
************ DEPENDING ON: HOUSEHOLDS' WEALTH ***************	



*We plot the relation at baseline between fertility and wealth
set scheme rainbow		
preserve
collapse number_children_bl if time==0, by(HH_Asset_Index_bl)
scatter number_children_bl HH_Asset_Index_bl , connect(1) ytitle(Number of children at baseline) xtitle(Household asset index)
graph export  "${DOT_output}/graph_wealth.png", replace as (png)
restore		
			
**We compute the median 
sum HH_Asset_Index_bl if time==0, det
return list

gen asset_below_med = (HH_Asset_Index_bl<r(p50))
replace asset_below_med = . if HH_Asset_Index_bl==.

gen asset_below_med_DOT_1 = asset_below_med*DOT_1
label var  asset_below_med_DOT_1 "Assets below median X DOT_1"

gen asset_below_med_DOT_2 = asset_below_med*DOT_2
label var  asset_below_med_DOT_2 "Assets below median X DOT_2"

local asset_below = "asset_below_med asset_below_med_DOT_1 asset_below_med_DOT_2"

reg n_children_t  DOT_1  DOT_2  time number_children_bl  married_couple WEDP_loan education_level_bl  Age_bl Age_bl_square head_hh bl_pi6 plan_have_children no_children_bl  if Age_bl<50 & asset_below_med==0, vce(cluster wedp_id) 
  sum  n_children_t if treatment==0 & time==0 & asset_below_med==0
    local C_mean = r(mean)
outreg2  using "${DOT_output}/HTE_wealth.xls", excel dec(3) ctitle("Household asset above the median") keep( DOT_1  DOT_2  ) addstat(Control group mean , `C_mean')    label replace

reg n_children_t  DOT_1  DOT_2  time number_children_bl  married_couple WEDP_loan education_level_bl  Age_bl Age_bl_square head_hh bl_pi6  plan_have_children no_children_bl if Age_bl<50 & asset_below_med==1, vce(cluster wedp_id) 
  sum  n_children_t if treatment==0 & time==0 & asset_below_med==1
    local C_mean = r(mean)
outreg2  using "${DOT_output}/HTE_wealth.xls", excel dec(3) ctitle("Household asset below the median") keep(  DOT_1 DOT_2   ) addstat(Control group mean , `C_mean') label append

 reg n_children_t  DOT_1  DOT_2 time  number_children_bl time married_couple  WEDP_loan education_level_bl  Age_bl Age_bl_square head_hh bl_pi6 plan_have_children no_children_bl if Age_bl<50 & asset_below_med==0
 est store reg1
reg n_children_t  DOT_1  DOT_2  time number_children_bl time married_couple  WEDP_loan education_level_bl  Age_bl Age_bl_square head_hh bl_pi6 plan_have_children no_children_bl if Age_bl<50 & asset_below_med==1
 est store reg2

suest reg1 reg2, vce(cluster wedp_id)
			test [reg1_mean]DOT_1 =[reg2_mean]DOT_1 
			local p_val_1 = r(p)
			test [reg1_mean]DOT_2=[reg2_mean]DOT_2
			local p_val_2 = r(p)
 putexcel set "${DOT_output}/HTE_wealth_test.xlsx", sheet("test diff")  replace
 putexcel A1="p-val period 1" B1="p-val period 2"
  putexcel A2=`p_val_1' B2=`p_val_2'
			
************ DEPENDING ON: WOMEN ACCESS TO FREE DAYCARE ***************



gen free_daycare = (bl_pi13 ==1 | bl_pi13 ==2 | bl_pi13 ==4)
replace free_daycare = . if bl_pi13==.

gen free_daycare_DOT1 = free_daycare*DOT_1
label var free_daycare_DOT1 "free daycare X DOT_1"

gen free_daycare_DOT2 = free_daycare*DOT_2
label var free_daycare_DOT2 "free daycare X DOT_2"


**If we split the sample 
reg n_children_t  DOT_1  DOT_2  number_children_bl time married_couple WEDP_loan education_level_bl  Age_bl Age_bl_square head_hh bl_pi6 plan_have_children no_children_bl HH_Asset_Index_bl if Age_bl<50 & free_daycare==1,  vce(cluster wedp_id)
  sum  n_children_t if treatment==0 & time==0 & free_daycare==1
    local C_mean = r(mean)
outreg2  using "${DOT_output}/HTE_daycare.xls", excel dec(3) ctitle("Free daycare") keep(DOT_1  DOT_2   )addstat(Control group mean, `C_mean')  label replace


reg n_children_t  DOT_1  DOT_2   number_children_bl time married_couple WEDP_loan education_level_bl  Age_bl Age_bl_square head_hh bl_pi6 plan_have_children no_children_bl HH_Asset_Index_bl if Age_bl<50 & free_daycare==0, vce(cluster wedp_id)
  sum  n_children_t if treatment==0 & time==0 &  free_daycare==0
    local C_mean = r(mean)
outreg2  using "${DOT_output}/HTE_daycare.xls", excel dec(3) ctitle("No free daycare") keep(DOT_1  DOT_2   )addstat(Control group mean, `C_mean') label append

reg n_children_t  DOT_1  DOT_2  number_children_bl time married_couple WEDP_loan education_level_bl  Age_bl Age_bl_square head_hh bl_pi6 plan_have_children no_children_bl HH_Asset_Index_bl if Age_bl<50 & free_daycare==0
 est store reg1
reg n_children_t  DOT_1  DOT_2   number_children_bl time married_couple WEDP_loan education_level_bl  Age_bl Age_bl_square head_hh bl_pi6 plan_have_children no_children_bl HH_Asset_Index_bl if Age_bl<50 & free_daycare==1
 est store reg2

suest reg1 reg2, vce(cluster wedp_id)
			test [reg1_mean]DOT_1 =[reg2_mean]DOT_1 
			local p_val_1 = r(p)
			test [reg1_mean]DOT_2=[reg2_mean]DOT_2
			local p_val_2 = r(p)
 putexcel set "${DOT_output}/HTE_daycare_test.xlsx", sheet("test diff")  replace
 putexcel A1="p-val period 1" B1="p-val period 2"
  putexcel A2=`p_val_1' B2=`p_val_2'			
			
			
************ DEPENDING ON: SON AND HOUSEHOLDS' WEALTH ***************

local at_least_s = "at_least_son at_least_son_DOT_1 at_least_son_DOT_2"


reg n_children_t  DOT_1  DOT_2  `at_least_s' time number_children_bl  married_couple WEDP_loan education_level_bl  Age_bl Age_bl_square head_hh bl_pi6 plan_have_children no_children_bl  if Age_bl<50 & asset_below_med==0, vce(cluster wedp_id) 
sum  n_children_t if treatment==0 & time==0 & asset_below_med==0
local C_mean = r(mean)
lincom  _b[at_least_son_DOT_1] 
local beta_1 =   string( r(estimate) ,"%10.3f")
local  Pval_1=  string(2 * (1-normal(abs(r(estimate) / r(se)))) ,"%10.3f" ) 
lincom  _b[at_least_son_DOT_2] 
local beta_2 =   string( r(estimate) ,"%10.3f")
local  Pval_2=  string(2 * (1-normal(abs(r(estimate) / r(se)))) ,"%10.3f" ) 
lincom  _b[DOT_1] + _b[at_least_son_DOT_1] 
local beta_3 =   string( r(estimate) ,"%10.3f")
local  Pval_3=  string(2 * (1-normal(abs(r(estimate) / r(se)))) ,"%10.3f" ) 
lincom  _b[DOT_2] + _b[at_least_son_DOT_2] 
local beta_4 =   string( r(estimate) ,"%10.3f")
local  Pval_4=  string(2 * (1-normal(abs(r(estimate) / r(se)))) ,"%10.3f" ) 

outreg2  using "${DOT_output}/HTE_son_wealth.xls", excel dec(3) ctitle("Household asset above the median") keep( DOT_1  DOT_2 `at_least_s'  ) addstat(Control group mean , `C_mean') addtext( Interaction term 1, `beta_1' , p-value 1, `Pval_1' , interaction term 2, `beta_2' , p-value 2, `Pval_2' , Treatment + Treatment X son period 1,  `beta_3', p-value 3, `Pval_3', Treatment + Treatment X son period 2,  `beta_4', p-value 4, `Pval_4')   label replace



reg n_children_t  DOT_1  DOT_2  `at_least_s' time number_children_bl  married_couple WEDP_loan education_level_bl  Age_bl Age_bl_square head_hh bl_pi6 plan_have_children no_children_bl  if Age_bl<50 & asset_below_med==1, vce(cluster wedp_id) 
sum  n_children_t if treatment==0 & time==0 & asset_below_med==1
local C_mean = r(mean)
lincom  _b[at_least_son_DOT_1] 
local beta_1 =   string( r(estimate) ,"%10.3f")
local  Pval_1=  string(2 * (1-normal(abs(r(estimate) / r(se)))) ,"%10.3f" ) 
lincom  _b[at_least_son_DOT_2] 
local beta_2 =   string( r(estimate) ,"%10.3f")
local  Pval_2=  string(2 * (1-normal(abs(r(estimate) / r(se)))) ,"%10.3f" ) 
lincom  _b[DOT_1] + _b[at_least_son_DOT_1] 
local beta_3 =   string( r(estimate) ,"%10.3f")
local  Pval_3=  string(2 * (1-normal(abs(r(estimate) / r(se)))) ,"%10.3f" ) 
lincom  _b[DOT_2] + _b[at_least_son_DOT_2] 
local beta_4 =   string( r(estimate) ,"%10.3f")
local  Pval_4=  string(2 * (1-normal(abs(r(estimate) / r(se)))) ,"%10.3f" ) 

outreg2  using "${DOT_output}/HTE_son_wealth.xls", excel dec(3) ctitle("Household asset below the median") keep( DOT_1  DOT_2 `at_least_s'  ) addstat(Control group mean , `C_mean') addtext( Interaction term 1, `beta_1' , p-value 1, `Pval_1' , interaction term 2, `beta_2' , p-value 2, `Pval_2' , Treatment + Treatment X son period 1,  `beta_3', p-value 3, `Pval_3', Treatment + Treatment X son period 2,  `beta_4', p-value 4, `Pval_4')   label append

reg n_children_t  DOT_1  DOT_2 time `at_least_s'  number_children_bl time married_couple  WEDP_loan education_level_bl  Age_bl Age_bl_square head_hh bl_pi6 plan_have_children no_children_bl if Age_bl<50 & asset_below_med==0
est store reg1
reg n_children_t  DOT_1  DOT_2  time `at_least_s' number_children_bl time married_couple  WEDP_loan education_level_bl  Age_bl Age_bl_square head_hh bl_pi6 plan_have_children no_children_bl if Age_bl<50 & asset_below_med==1
est store reg2

suest reg1 reg2, vce(cluster wedp_id)

test [reg1_mean]DOT_1 =[reg2_mean]DOT_1
local p_val_1 = r(p)
test [reg1_mean]DOT_2=[reg2_mean]DOT_2
local p_val_2 = r(p)
test [reg1_mean]at_least_son_DOT_1 =[reg2_mean]at_least_son_DOT_1
local p_val_3 = r(p)
test [reg1_mean]at_least_son_DOT_2=[reg2_mean]at_least_son_DOT_2
local p_val_4 = r(p)
putexcel set "${DOT_output}/HTE_son_wealth_test.xlsx", sheet("test diff")  replace
 putexcel A1="Difference test p-val: Treatment follow-up 1" B1="Difference test p-val: Treatment follow-up 1" C1="Difference test p-val: Interaction follow-up 1" /// 
 D1 ="Difference test p-val: Interaction follow-up 2"  
putexcel A2=`p_val_1' B2=`p_val_2' C2=`p_val_3' D2=`p_val_4'





************ ROBUSTNESS CHEKS: INTERACTION OF THE TREATMENT WITH THE NBS OF CHILDREN AT BASELINE AND THE SON STATUS***************


gen  nbs_DOT_1 = DOT_1*number_children_bl
label var nbs_DOT_1 "Number of children X DOT_1"

gen  nbs_DOT_2 = DOT_2*number_children_bl
label var nbs_DOT_2 "Number of children X DOT_2"

local nbs_T =  "nbs_DOT_1 nbs_DOT_2"



reg n_children_t  DOT_1 DOT_2 at_least_son at_least_son_DOT_1 at_least_son_DOT_2 number_children_bl  nbs_DOT_1 nbs_DOT_2  time married_couple WEDP_loan education_level_bl  Age_bl Age_bl_square head_hh bl_pi6 plan_have_children no_children_bl  if Age_bl<50 , vce(cluster wedp_id) 
sum n_children_t  if treatment==0 
local C_mean_1 = r(mean)
outreg2  using  "${DOT_output}/HTE_son_nbs_children.xls", excel dec(3) ctitle("") keep( DOT_1 DOT_2 at_least_son at_least_son_DOT_1 at_least_son_DOT_2 number_children_bl  nbs_DOT_1 nbs_DOT_2  number_children_bl  ) addstat(Control group mean, `C_mean_1')  label replace


************ IMPACT OF THE TREATMENT ON WOMEN LABOUR SUPPLY ***************	

**Importing the var related to women labour supply 
preserve 
use "${DOT_data}/WEDP_DOT_BL_ML_EL_noPII_19Apr2022.dta", replace

rename sec42_24 el_sec42_24

rename sec42_25 el_sec42_25

rename digitspan_score bl_digitspan_score

keep if time==1
save "${DOT_data}/WEDP_DOT_BL_ML_EL_noPII_19Apr2022_el.dta", replace

restore 


merge m:1  wedp_id using "${DOT_data}/WEDP_DOT_BL_ML_EL_noPII_19Apr2022_bl_ml.dta", keepusing( ml_sec42_24  bl_HOURSworkedweek  bl_digitspan_score bl_numEMPLOYEES)


merge m:1  wedp_id using "${DOT_data}/WEDP_DOT_BL_ML_EL_noPII_19Apr2022_el.dta", keepusing(el_sec42_24 el_sec42_25) gen(_merge_el)

**outcomes seems to have been already winsorized 

replace el_sec42_24 = . if el_sec42_24== -77

replace ml_sec42_24 = . if ml_sec42_24== -77


 winsor2 bl_HOURSworkedweek if time==0, replace cuts(1 99)
 winsor2 bl_HOURSworkedweek if time==1, replace cuts(1 99)

**Buidling the outcome

gen hours_worked_weekly = ml_sec42_24 if time==0 
replace hours_worked_weekly = el_sec42_24  if time==1

**Estimation 

reg  hours_worked_weekly  DOT_1 DOT_2 bl_HOURSworkedweek  number_children_bl time married_couple WEDP_loan education_level_bl  Age_bl Age_bl_square head_hh bl_digitspan_score  if Age_bl<50, vce(cluster wedp_id) 
sum  bl_HOURSworkedweek if treatment==0 & time==0
local C_mean = r(mean)
outreg2  using "${DOT_output}/labour_supply.xls", excel dec(3) ctitle("") keep( DOT_1 DOT_2 ) addstat(Control group mean -follow-up 1, `C_mean')  label replace

test _b[DOT_1 ] =_b[DOT_2 ]
	

			