
*********************************
*******Balance check - TOGO******
*********************************

**Import baseline data
use "${TOGO_data}/BL_raw_an_old.dta", replace

gen treatment =  group

rename * bl_*

rename bl_id_entreprise  id_entreprise

*Merge with follow-up 3 

merge 1:1 id_entreprise using  "${TOGO_data}/FU3_raw_an_old.dta" ,keepusing(Follow_up p6q2a1 p6q2a2 interviewed) 

**********Define the attrition var*********
gen attrited_FU3 = (interviewed==0)

bysort bl_treatment: tab attrited_FU3


**********We define the treatment variables*********

gen PI = (bl_group==2)
label var PI "Personal initiative training"
gen Trad_training =(bl_group==1)
label var Trad_training "Traditional training"
gen control_group= (bl_group==3)

 
 
*****strata********

gen strata = bl_stratafinal



*******we prepare the database*********

gen female_respondent = (bl_q40==1)

gen female_age = bl_q41_age if female_respondent ==1
*replace female_age = q181 if (female_respondent ==0 & married_or_couple==1)

gen  Married = bl_q179
gen married_or_couple = (Married==1 | bl_q179b==1)
label var married_or_couple "Married or living with partner"

replace bl_q181 =. if bl_q181==3

gen female_educ = 1 if bl_q155==1 & female_respondent ==1
replace female_educ = 2 if bl_q155==2 |bl_q155==3 | bl_q155==4 |bl_q155==5 | bl_q155==6 | bl_q155==7 & female_respondent ==1
replace female_educ = 3 if  bl_q155==8 |bl_q155==9 | bl_q155==10 |bl_q155==11 & female_respondent ==1
replace female_educ = 4 if  bl_q155==12 |bl_q155==13 | bl_q155==14  & female_respondent ==1
replace female_educ = 5 if   bl_q156 ==1 | bl_q156 ==2 | bl_q156 ==3| bl_q156 ==4| bl_q156 ==5 | bl_q156 ==6 | bl_q156 ==7 | bl_q156 ==8 | bl_q156 ==14
label define educ 1 "No education" 2 "Primary education" 3 "Middle school" 4 "High school" 5 "Higher education"


*replace female_educ = q180 if  (female_respondent ==0 & married_or_couple==1)


egen nbs_hh_members = rowtotal(bl_q177_nb_hom_1 bl_q177_nb_hom_2 bl_q177_nb_hom_3 bl_q177_nb_hom_4 bl_q177_nb_hom_5 bl_q177_nb_fem_1 bl_q177_nb_fem_2 bl_q177_nb_fem_3 bl_q177_nb_fem_4 bl_q177_nb_fem_5)


 



tab  bl_q180, gen(educ_conjoint)

gen Nbs_children_under_5_BL = (bl_q177_nb_hom_1 +bl_q177_nb_fem_1)

gen conjoint_employed = (bl_q182==1|  bl_q182==5 | bl_q182==7 )
replace conjoint_employed=. if bl_q182==.
label var conjoint_employed "partner employed"
gen conjoint_self_employed = (bl_q182==2 | bl_q182==3 | bl_q182==4)
replace conjoint_self_employed=. if bl_q182==.
label var conjoint_self_employed "partner self employed"
gen conjoint_unemployed = ( bl_q182==9|  bl_q182==10| bl_q182==11)
replace conjoint_unemployed=. if bl_q182==.
label var conjoint_unemployed  "partner unemployed"
gen conjoint_other = (bl_q182==6| bl_q182==8)
replace conjoint_other =. if bl_q182==.
label var conjoint_other "Other"


tab female_educ, gen(fem_educ)

gen Married_formally = (Married==1) 
replace  Married_formally =. if Married==.



gen women_hh_head = (bl_q178==1 & female_respondent ==1)


***household asset index

alpha bl_q183a bl_q183b bl_q183c bl_q183d  bl_q183f bl_q183g bl_q183h bl_q183i bl_q183j bl_q183k bl_q183l bl_q183m bl_q183n, item
 
*The alpha reliability coefficient =0,7 
*with the option item, we see the item rtest correlation 
*We remove the q183e uncorrelated with the other (fer à repasser à charbon)

**TOP-CODING
foreach var of varlist bl_q183a bl_q183b bl_q183c bl_q183d  bl_q183f bl_q183g bl_q183h bl_q183i bl_q183j bl_q183k bl_q183l bl_q183m bl_q183n{

	sum `var', detail
	gen `var'_w =`var'
	 replace `var'_w=r(p99) if `var'>r(p99)&`var'!=.
	
	ta `var'_w,m 

}  

**STANDARDIZATION
foreach var of varlist  bl_q183a_w bl_q183b_w bl_q183c_w bl_q183d_w bl_q183f_w bl_q183g_w bl_q183h_w bl_q183i_w bl_q183j_w bl_q183k_w bl_q183l_w bl_q183m_w bl_q183n_w{

	sum `var' if female_age<50 & female_respondent==1 & married_or_couple==1
	gen `var'_st=(`var'-r(mean))/r(sd)

}

**COMPUTING THE INDEX
  icw_index bl_q183a_w_st bl_q183b_w_st bl_q183c_w_st bl_q183d_w_st bl_q183f_w_st bl_q183g_w_st bl_q183h_w_st bl_q183i_w_st bl_q183j_w_st bl_q183k_w_st bl_q183l_w_st bl_q183m_w_st bl_q183n_w_st, gen(hh_asset_index)
  
label var hh_asset_index "Household asset index-Anderson-on women of the sample"
   
drop  bl_q183a_w bl_q183b_w bl_q183c_w bl_q183d_w bl_q183f_w bl_q183g_w bl_q183h_w bl_q183i_w bl_q183j_w bl_q183k_w bl_q183l_w bl_q183m_w bl_q183n_w bl_q183a_w_st bl_q183b_w_st bl_q183c_w_st bl_q183d_w_st bl_q183f_w_st bl_q183g_w_st bl_q183h_w_st bl_q183i_w_st bl_q183j_w_st bl_q183k_w_st bl_q183l_w_st bl_q183m_w_st bl_q183n_w_st






**labeling 

label var female_age "female age"
label var female_educ "female education"
label var married_or_couple "Married"
label var  Nbs_children_under_5_BL "Number children under 5 in the household at baseline"
label var  bl_q180 "Partner level of education"
label var bl_q181 "Partner age"
label var bl_q182 "Partner occupation"
label var female_educ "Women education"
label var nbs_hh_members "Number of household members"
label var women_hh_head "women is hh head"
label var Married_formally "Married formally"


********GENERATING THE BC TABLE ***********

 global bc_var " female_age fem_educ1 fem_educ2 fem_educ3 fem_educ4 fem_educ5 nbs_hh_members Nbs_children_under_5_BL Married_formally women_hh_head  bl_q181 educ_conjoint1 educ_conjoint2 educ_conjoint3 educ_conjoint4 educ_conjoint5 conjoint_employed conjoint_self_employed conjoint_unemployed conjoint_other hh_asset_index" 

global bc_var_num : word count $bc_var
des $bc_var, fullname
 

#delimit ;
 
*Create the table's columns:;
*Column containing the list of baseline covariates;
gen str32 var="";                                                         
 
*Columns for sample description (n, mean, sd);
for any end: gen X_n=. ;
for any end: gen X_mean=. ;
for any end: gen X_sd=. ;
 
*Columns for balancing tests;
for any treatment : gen X_mean=. \ gen X_pv=. \ gen X_sig="" \ gen X_se=.;
 
***1/ATTRITION;
replace var="Attrition" if _n==1;
 
sum attrited_FU3 if female_age<50 & female_respondent ==1 & married_or_couple==1 & Trad_training==0, detail; 
 
            replace end_mean=r(mean) if _n==1;
            replace end_sd=r(sd) if _n==1;
sum attrited_FU3 if female_age<50 & female_respondent ==1 & married_or_couple==1 , detail; 
            replace end_n=r(N) if _n==1;
 
xi: reg attrited_FU3 PI  Trad_training if female_age<50 & female_respondent ==1 & married_or_couple==1, a(strata) ;
           
     replace treatment_mean=_b[PI] if _n==1;
            replace treatment_se=_se[PI] if _n==1;
            test PI;
            replace treatment_pv=r(p) if _n==1;
           
***2/OTHER CHARACTERISTICS;
local vars $bc_var_num ;
 
for any $bc_var \ num 1/`vars':
 
replace var="X" if _n==(Y+1) \
 
sum X if attrited_FU3==0 &  control_group==1   & female_age<50 & female_respondent ==1 & married_or_couple==1, detail \
 
            replace end_mean=r(mean) if _n==(Y+1) \
            replace end_sd=r(sd) if _n==(Y+1) \
sum X if attrited_FU3==0  & female_age<50 & female_respondent ==1 & married_or_couple==1, detail \
            replace end_n=r(N) if _n==(Y+1) \
 
xi: reg X PI Trad_training if  female_age<50 & female_respondent ==1 & attrited==0 & married_or_couple==1,  a(strata)  \
             
     replace treatment_mean=_b[PI] if _n==(Y+1) \    
             replace treatment_se=_se[PI] if _n==(Y+1) \     
             test PI\
            replace treatment_pv=r(p) if _n==(Y+1) ;
           
*ROUNDING UP;
for var *_mean *_pv *_se : replace X=round(X, 0.0001);
 
*SIGNIFICANCE LEVEL;
for any treatment : replace X_sig=" " if (X_pv>0.1);
for any treatment: replace X_sig="*" if (X_pv>0.05&X_pv<=0.1);
for any treatment: replace X_sig="**" if (X_pv>0.01&X_pv<=0.05);
for any treatment : replace X_sig="***" if (X_pv<=0.01);
 
*REPLACING VARIABLE NAMES BY THEIR LABEL;
foreach var in $bc_var {;
 
            replace var=`"`:var label `var''"' if var=="`var'";
 
};
 
 
 
 gen ordering_var = _n ;




#delimit cr




gen Pval_H_Unadj = treatment_pv 

		sort Pval_H_Unadj 
		gen Pval_H_Unadj_order = _n if Pval_H_Unadj != . 
		egen m= max(Pval_H_Unadj_order) if Pval_H_Unadj != . 
		gen Pval_Adj = . 
		replace Pval_Adj = min(Pval_H_Unadj * m / Pval_H_Unadj_order,1) if Pval_H_Unadj_order != . 
		
		drop Pval_H_Unadj 
	for var Pval_Adj : replace X=round(X, 0.0001)
 
 sort ordering_var


 
 
*SAVING TABLE;
export excel var end_n end_mean end_sd  treatment_mean treatment_se treatment_pv Pval_Adj treatment_sig  using "${TOGO_output}/Sample description and balance checks-TOGO.xlsx", replace  keepcellfmt firstrow(var)

drop var end_n end_mean end_sd treatment_mean treatment_pv treatment_sig treatment_se

