*********************************
*******Balance check - WALN******
*********************************





*Import data
use "${WALN_data}/prepared_data.dta", replace


*Sampling

**We keep only mentors  (because no impact on profit for the mentees)
keep if status_mentorship_s_bl==0

*We keep womem hh head and or women who are spouse of the hh head 
 keep if (a214_2==1 | a214_2==4)
 

**cleaning 
 
*Age

gen Age =a124_bl
replace a216_2=. if a216_2<18 
label var  a216_2 "Head/spouse age"
label var Age "Age"
*Primary occupation 
 label var a218_2 "Head/spouse primary occupation"
 
*Married 
gen married = (a217_1_bl==1)
replace married = . if a217_1_bl==.
 
*Head Education 
gen Head_education_level = a219_2
replace Head_education_level=0 if (a219_2==17 |a219_2==18 |a219_2==19 |a219_2==20)
 
label define educ_1 0 "No education" 1 "1st Grade" 2 "2nd Grade" 3 "3rd Grade" 4  "4th Grade"  5 "5th Grade" 6  "6th Grade" 7  "7th Grade"  8  "8th Grade" 9  "9th Grade"  10  "10th Grade" 11  "11th Grade" 12  "12th Grade" 13  "Incomplete higher education (not university)" 14 "Completed higher education (not university)"15 "Incomplete university education" 16 "Completed university"
        
label values  Head_education_level educ_1

label var Head_education_level "Head/spouse highest level of education"
 
***We clean the variable to harmonize the tables:
 
 *partner education 

 
 gen partner_no_educ = ( Head_education_level==0 )
 replace  partner_no_educ=. if Head_education_level==.
 label var partner_no_educ "Partner no education"
 
 gen partner_prim_educ = ( Head_education_level==1| Head_education_level==2| Head_education_level==3| Head_education_level==4| Head_education_level==5| Head_education_level==6| Head_education_level==7| Head_education_level==8)
replace  partner_prim_educ=. if Head_education_level==.
label var partner_prim_educ "partner primary education"

gen partner_sec_educ = ( Head_education_level==9| Head_education_level==10)
replace  partner_sec_educ=. if Head_education_level==.
label var partner_sec_educ "partner secondary education"


gen partner_high_s_educ = ( Head_education_level==11| Head_education_level==12)
replace  partner_high_s_educ=. if Head_education_level==.
label var partner_high_s_educ "partner high school"

gen partner_higher_educ = ( Head_education_level==13| Head_education_level==14 | Head_education_level==15| Head_education_level==16)
replace  partner_higher_educ=. if Head_education_level==.
label var partner_higher_educ "partner higher education"



**woman education 


gen women_no_educ = (a219_1_bl==17| a219_1_bl==18| a219_1_bl==19|a219_1_bl==20)
 replace  women_no_educ=. if a219_1_bl==.
 label var women_no_educ "women no education"
 
 gen women_prim_educ = (a219_1_bl==1| a219_1_bl==2| a219_1_bl==3| a219_1_bl==4| a219_1_bl==5|a219_1_bl==6| a219_1_bl==7| a219_1_bl==8)
replace  women_prim_educ=. if a219_1_bl==.
label var women_prim_educ "women primary education"

gen women_sec_educ = ( a219_1_bl==9| a219_1_bl==10)
replace  women_sec_educ=. if a219_1_bl==.
label var women_sec_educ "women secondary education"


gen women_high_s_educ = ( a219_1_bl==11| a219_1_bl==12)
replace  women_high_s_educ=. if a219_1_bl==.
label var women_high_s_educ "women high school"

gen women_higher_educ = ( a219_1_bl==13| a219_1_bl==14 | a219_1_bl==15| a219_1_bl==16)
replace  women_higher_educ=. if a219_1_bl==.
label var women_higher_educ "women higher education"


**Spouse primary occ
encode a218_2_bl, gen (a218_2_n)

gen partner_farmer = (a218_2_n ==7 | a218_2_n ==11 )
replace partner_farmer=. if a218_2_n==.
label var partner_farmer "Partner farmer or family farm worker"

gen partner_self_employed = (a218_2_n ==1| a218_2_n ==3 |a218_2_n ==6|a218_2_n ==8 |a218_2_n ==14|a218_2_n ==20 | a218_2_n ==22| a218_2_n ==23)
replace partner_self_employed = . if a218_2_n==.
label var partner_self_employed "Partner self employed"


gen partner_employed = (a218_2_n ==2 | a218_2_n ==9 | a218_2_n ==10 |a218_2_n ==13 |a218_2_n ==16 |a218_2_n ==17 |a218_2_n ==18|a218_2_n ==21 )
replace partner_employed = . if a218_2_n==.
label var partner_employed "Partner employed"

gen partner_unemployed = (a218_2_n ==4 | a218_2_n ==5 | a218_2_n ==12 |a218_2_n ==19)
replace partner_unemployed = . if a218_2_n==.
label var partner_unemployed "Partner unemployed"

gen partner_other = (a218_2_n ==15)
replace partner_other = . if a218_2_n==.
label var partner_other "other"


**The main outcome "number of children" is only available at fu1 and fu3, so we are interested only in these two periods

 gen follow_up= 1 if survey_round =="_fu1"
  replace follow_up= 2 if survey_round =="_fu2"
   replace follow_up= 3 if survey_round =="_fu3"
 
   gen Dmentor_1 = (Dmentor==1 & follow_up==1)
   replace Dmentor_1=. if Dmentor==. 
  replace Dmentor_1=. if follow_up==.
    replace Dmentor_1=. if follow_up==2
   
    gen Dmentor_2 = (Dmentor==1 & follow_up==3)
   replace Dmentor_2=. if Dmentor==. 
      replace Dmentor_1=. if follow_up==.
    replace Dmentor_1=. if follow_up==2

	
**Control group: 
gen control = (Dmentor==0)	
		

**strata 

encode  mentor_strat_bl, gen( mentor_strat_bl_1)		

*labelling 
label var a211a_bl "nbs of household members"	
label var num_child_bl "Nbs of children at baseline"	
label var married "married"
label var a211_bl "women hh head"
		
global bc_var  "Age women_no_educ women_prim_educ women_sec_educ women_high_s_educ women_higher_educ a211_bl a211a_bl num_child_bl  married    a216_2 partner_no_educ partner_prim_educ partner_sec_educ partner_high_s_educ partner_higher_educ partner_farmer partner_self_employed partner_employed partner_unemployed partner_other"


 
global bc_var_num : word count $bc_var
des $bc_var, fullname
 

#delimit ;
 
*Create the table's columns:;
*Column containing the list of baseline covariates;
gen str32 var="";                                                         
 
*Columns for sample description (n, mean, sd);
for any end: gen X_n=. ;
for any end: gen X_mean=. ;
for any end: gen X_sd=. ;
 
*Columns for balancing tests;
for any treatment : gen X_mean=. \ gen X_pv=. \ gen X_sig="" \ gen X_se=.;
 
***1/ATTRITION;
replace var="Attrition" if _n==1;
 
sum attrited_fu3 if Age<50 & follow_up==3 & control==1, detail; 
 
            replace end_mean=r(mean) if _n==1;
            replace end_sd=r(sd) if _n==1;
			
sum attrited_fu3 if Age<50 & follow_up==3 , detail; 
            replace end_n=r(N) if _n==1;
 
xi: reg attrited_fu3 Dmentor_2 i.mentor_strat_bl_1 if Age<50 & follow_up==3 & married==1 ;
           
     replace treatment_mean=_b[Dmentor_2] if _n==1;
            replace treatment_se=_se[Dmentor_2] if _n==1;
            test Dmentor_2;
            replace treatment_pv=r(p) if _n==1;
           
***2/OTHER CHARACTERISTICS;
local vars $bc_var_num ;
 
for any $bc_var \ num 1/`vars':
 
replace var="X" if _n==(Y+1) \
 
sum X if attrited_fu3==0 & follow_up==3 & Dmentor_2==0 & Age<50 & married==1, detail \
 
            replace end_mean=r(mean) if _n==(Y+1) \
            replace end_sd=r(sd) if _n==(Y+1) \
			
sum X if attrited_fu3==0 & follow_up==3 & Age<50 &  married==1, detail \
            replace end_n=r(N) if _n==(Y+1) \
 
xi: reg X  Dmentor_2 i.mentor_strat_bl_1 if attrited_fu3==0 & follow_up==3 & Age<50 & married==1 \
             
     replace treatment_mean=_b[Dmentor_2] if _n==(Y+1) \    
             replace treatment_se=_se[Dmentor_2] if _n==(Y+1) \     
             test Dmentor_2\
            replace treatment_pv=r(p) if _n==(Y+1) ;
           
*ROUNDING UP;
for var *_mean *_pv *_se: replace X=round(X, 0.0001);
 
*SIGNIFICANCE LEVEL;
for any treatment : replace X_sig=" " if (X_pv>0.1);
for any treatment: replace X_sig="*" if (X_pv>0.05&X_pv<=0.1);
for any treatment: replace X_sig="**" if (X_pv>0.01&X_pv<=0.05);
for any treatment : replace X_sig="***" if (X_pv<=0.01);
 
*REPLACING VARIABLE NAMES BY THEIR LABEL;
foreach var in $bc_var {;
 
            replace var=`"`:var label `var''"' if var=="`var'";
 
};

gen ordering_var = _n ;




#delimit cr




gen Pval_H_Unadj = treatment_pv 

		sort Pval_H_Unadj 
		gen Pval_H_Unadj_order = _n if Pval_H_Unadj != . 
		egen m= max(Pval_H_Unadj_order) if Pval_H_Unadj != . 
		gen Pval_Adj = . 
		replace Pval_Adj = min(Pval_H_Unadj * m / Pval_H_Unadj_order,1) if Pval_H_Unadj_order != . 
		
		drop Pval_H_Unadj 
	for var Pval_Adj : replace X=round(X, 0.0001)
 
 sort ordering_var





 
*SAVING TABLE;
export excel var end_n end_mean end_sd treatment_mean treatment_se treatment_pv Pval_Adj treatment_sig  using "${WALN_output}/Sample description and balance checks - WALN.xlsx", replace   keepcellfmt  firstrow(var)


drop var var end_n end_mean end_sd treatment_mean treatment_pv treatment_sig treatment_se
